## This function normalizes the SHAPE data using the threshold method
##
## K. Zarringhalam
normalize.piecwise = function(shape.dat, thresh.l = 0.25, thresh.m = 0.3, thresh.h = 0.7, out.file){
  
  low.p  = 0.35
  mid.p  = 0.55
  high.p = 0.85
  
  
  ## Eleminating -999
  shape.ind = (1:length(shape.dat$V2)) > 0
  shape.ind[which(shape.dat$V2 == "-999")] = FALSE
  
  ## Seting the thersholds for highly and highly highly reactive
  shape.l = thresh.l
  shape.m = thresh.m
  shape.h = thresh.h
  
  mx.shape = max(shape.dat$V2[shape.ind])
  mn.shape = min(shape.dat$V2[shape.ind])
  
  shape.good  = shape.dat$V2[shape.ind]
  shape.scale = shape.good * 0
  
  ## First interval [mn, shape.l] --> [0.0, low.p]
  int1= which(shape.good <= shape.l)
  scale1 = ((low.p - 0.0) / (shape.l - mn.shape))
  shape.scale[int1] = scale1 * (shape.good[int1] - mn.shape) + 0.0
  
  ## Second interval [shape.l, shape.m] --> [low.p, mid.p]
  int2.1 = which(shape.good > shape.l)
  int2.2 = which(shape.good[int2.1] <= shape.m)
  int2   = int2.1[int2.2]
  scale2 = ((mid.p - low.p) / (shape.m - shape.l))
  shape.scale[int2] = scale2 * (shape.good[int2] - shape.l) + low.p
  
  ## Third interval [shape.m, shape.h] --> [mid.p, high.p]
  int3.1 = which(shape.good > shape.m)
  int3.2 = which(shape.good[int3.1] <= shape.h)
  int3   = int3.1[int3.2]
  scale3 = ((high.p - mid.p) / (shape.h - shape.m))
  shape.scale[int3] = scale3 * (shape.good[int3] - shape.m) + mid.p
  
  ## Forth interval [shape.h, mx] --> [high.p, 1.0]
  int4 = which(shape.good > shape.h)
  scale4 = ((1 - high.p) / (mx.shape - shape.h))
  shape.scale[int4] = scale4 * (shape.good[int4] - shape.h) + high.p
  
  ## Putting the missing value back into the vector
  shape.final = rep(0.5, length(shape.dat$V2))
  shape.final[shape.ind] = shape.scale
  
  ## writting the output
  write.table(cbind(shape.dat$V1, shape.final), out.file, quote = F, row.names = F, col.names = F, sep = '\t')
}
