#!/usr/bin/python
#
# This function reads the basepairing probability file generated by
# RNAsc and computes the probabilities of the nucleotides not
# being base-paired.
#
#
# Input Arguments:
#
# bp_file     -   base-pairing probability file.
#
# prob_out    -   output probabilities of single nucleotides not being
#                 base-paired.
#
#
# USAGE: ./read_write_shape_bp.py -i bp_file -o prob_out

import sys
from optparse import OptionParser


    
# Main function
if __name__ == "__main__":
    # Parsing the input arguments
    parser = OptionParser()
    parser.add_option("-i", dest = "bp_file_name",
                      help = "Path to the input base-pairing probability file",
                      metavar = "FILE")
    
    parser.add_option("-o", dest = "prob_out_name",
                      help = "Path to the output probabilities of nucleotides not being base-paired",
                      metavar = "FILE")

    (options, args) = parser.parse_args()

    # Inputs
    bp_file  = open(options.bp_file_name, 'r')
    prob_out = open(options.prob_out_name, 'w')

    # Reading the probabilities
    bp_line = bp_file.readline().strip().split()
    n = int(len(bp_line))
    
    Q = {}
    P = {}
    P[0] = [float(item) for item in bp_line]
    Q[0] = 1.0

    for i in range(1, n):
        bp_line = bp_file.readline().strip().split()
        P[i] = [float(item) for item in bp_line]
        Q[i] = 1.0

    for i in range(0, n):
        sum = 0.0
        for j in range(0, n):
            if i < j:
                sum = sum + P[i][j]
            elif j < i:
                sum = sum + P[j][i]
        Q[i] = 1.0 - sum
        prob_out.writelines(str(Q[i]) + '\n')
    
    bp_file.close()
    prob_out.close()
