#! /bin/bash
#
# This script runs Fold and ct2dot and outputs the results. It also
# silences the progress bar (good for parsing the output)
# 
#
# Note: Pay attention to the directory hierarchies or fix the path to
# the binaries
#
# K. Zarringhalam

USAGE="Usage: `basename $0` -s seq_file -i shape.dat -a alpha -b beta"

if [ $# -eq 0 ]; then
    echo $USAGE >&2
    exit 1
fi

# parse command line arguments
while getopts s:i:a:b: OPT; do
    case "$OPT" in
        s)SHAPE_SEQ=$OPTARG
            ;;
        i)SHAPE_DAT=$OPTARG
            ;;
        a)ALPHA=$OPTARG
            ;;
        b)BETA=$OPTARG
            ;;
        \?)
            echo $USAGE >&2
            exit 1
            ;;
    esac
done

export DATAPATH=../data_tables/

# Folding

FOLD_FILE=${SHAPE_SEQ}."fold"
PRAN_FILE="tmp.pran"
FOLD_ERR="draw_prep.err"
PRAN_ERR="draw.err"

./Fold $SHAPE_SEQ $FOLD_FILE --SHAPE $SHAPE_DAT -si $ALPHA -sm $BETA 1>/dev/null 2>$FOLD_ERR
./ct2dot $FOLD_FILE 1 $PRAN_FILE 1>/dev/null 2>$PRAN_ERR
cat $PRAN_FILE
