#! /bin/bash
#
# This script runs the RNAstructure partition function while
# incorporating the shape reactivitity data. It then generates the
# Boltzmann basepairing probabilities and then the probabilities of
# single nucleotides NOT being base-paired.
#
# Note: Pay attention to the directory hierarchies or fix the path to
# the binaries
#
# K. Zarringhalam

USAGE="Usage: `basename $0` -s seq_file -i shape.dat -p output_bpp_file -o output_prob_file -a alpha -b beta"

if [ $# -eq 0 ]; then
    echo $USAGE >&2
    exit 1
fi

# parse command line arguments
while getopts s:i:p:o:a:b: OPT; do
    case "$OPT" in
        s)SHAPE_SEQ=$OPTARG
            ;;
        i)SHAPE_DAT=$OPTARG
            ;;
        p)PROB_FILE=$OPTARG
            ;;
        o)OUT_FILE=$OPTARG
            ;;
        a)ALPHA=$OPTARG
            ;;
        b)BETA=$OPTARG
            ;;
        \?)
            echo $USAGE >&2
            exit 1
            ;;
    esac
done

# Generating the partition function
export DATAPATH=../data_tables/
PART_ERR="tmp_prob.err"
./partition $SHAPE_SEQ $PROB_FILE --SHAPE $SHAPE_DAT -si $ALPHA -sm $BETA 1>/dev/null 2> $PART_ERR
#./partition $SHAPE_SEQ $PROB_FILE --SHAPE $SHAPE_DAT -si $ALPHA -sm $BETA


# Generating the probabilities of nucleotides Not being base paired.
./read_write_shape_bp.py -i $PROB_FILE -o $OUT_FILE
